@@ -6,7 +6,8 @@
 #define   MRetryAbort        L"_Retry_Abort"
 #define   MCopyright         L"\nRAR %s   Copyright (c) 1993-%d Alexander Roshal   %d %s %d"
 #define   MRegTo             L"\nRegistered to %s\n"
-#define   MShare             L"\nTrial version             Type RAR -? for help\n"
+#define   MShare             L"\nTrial version             Type 'rar -?' for help\n"
+#define   MRegKeyWarning     L"\nAvailable license key is valid only for %s\n"
 #define   MUCopyright        L"\nUNRAR %s freeware      Copyright (c) 1993-%d Alexander Roshal\n"
 #define   MBeta              L"beta"
 #define   Mx86               L"x86"
@@ -130,7 +131,7 @@
 #define   MCHelpSwTO         L"\n  to<time>      Process files older than <time>"
 #define   MCHelpSwTA         L"\n  ta<date>      Process files modified after <date> in YYYYMMDDHHMMSS format"
 #define   MCHelpSwTB         L"\n  tb<date>      Process files modified before <date> in YYYYMMDDHHMMSS format"
-#define   MCHelpSwTS         L"\n  ts<m,c,a>[N]  Save or restore file time (modification, creation, access)"
+#define   MCHelpSwTS         L"\n  ts[m|c|a]     Save or restore file time (modification, creation, access)"
 #define   MCHelpSwU          L"\n  u             Update files"
 #define   MCHelpSwV          L"\n  v             Create volumes with size autodetection or list all volumes"
 #define   MCHelpSwVUnr       L"\n  v             List all volumes"
@@ -277,9 +278,7 @@
 #define   MListHostOS        L"Host OS"
 #define   MListFileVer       L"File version"
 #define   MListService       L"Service"
-#define   MListEAHead        L"\n   OS/2 extended attributes"
 #define   MListUOHead        L"\n   Unix Owner/Group data:    %-14s %-14s"
-#define   MListBeEAHead      L"\n   BeOS extended attributes"
 #define   MListNTACLHead     L"\n   NTFS security data"
 #define   MListStrmHead      L"\n   NTFS stream: %s"
 #define   MListUnkHead       L"\n   Unknown subheader type: 0x%04x"
@@ -322,14 +321,7 @@
 #define   MStreamBroken      L"\nERROR: %s stream data are corrupt\n"
 #define   MStreamUnknown     L"\nWARNING: Unknown format of %s stream data\n"
 #define   MInvalidName       L"\nERROR: Invalid file name %s"
-#define   MEABroken          L"\nERROR: %s extended attributes are corrupt\n"
-#define   MEAUnknHeader      L"\nWARNING: %s - unknown format of extended attributes\n"
-#define   MCannotSetEA       L"\nWARNING: cannot set extended attributes to %s\n"
-#define   MCannotGetEA       L"\nERROR: Cannot get extended attributes of %s\n"
-#define   MShowEA            L" (+EA)"
-#define   MSkipEA            L"\n...skipping extended attributes"
 #define   MProcessArc        L"\n\nProcessing archive %s"
-#define   MSyncScanError     L"\nFile search errors, cannot synchronize archive"
 #define   MCorrectingName    L"\nWARNING: Attempting to correct the invalid file name"
 #define   MUnpCannotMerge    L"\nWARNING: You need to start extraction from a previous volume to unpack %s"
 #define   MUnknownOption     L"\nERROR: Unknown option: %s"
@@ -378,6 +370,7 @@
 #define   MSearchDupFiles    L"\nSearching for identical files"
 #define   MNumFound          L"%d found."
 #define   MUnknownExtra      L"\nUnknown extra field in %s."
+#define   MCorruptExtra      L"\nCorrupt %s extra field in %s."
 #define   MCopyError         L"\nCannot copy %s to %s."
 #define   MCopyErrorHint     L"\nYou need to unpack the entire archive to create file reference entries."
 #define   MCopyingData       L"\nCopying data"
