@@ -6,8 +6,8 @@ UIASKREP_RESULT uiAskReplace(wchar *Name,size_t MaxNameSize,int64 FileSize,RarTi
   FindData ExistingFD;
   memset(&ExistingFD,0,sizeof(ExistingFD)); // In case find fails.
   FindFile::FastFind(Name,&ExistingFD);
-  itoa(ExistingFD.Size,SizeText1);
-  ExistingFD.mtime.GetText(DateStr1,ASIZE(DateStr1),true,false);
+  itoa(ExistingFD.Size,SizeText1,ASIZE(SizeText1));
+  ExistingFD.mtime.GetText(DateStr1,ASIZE(DateStr1),false);
 
   if (FileSize==INT64NDF || FileTime==NULL)
   {
@@ -16,8 +16,8 @@ UIASKREP_RESULT uiAskReplace(wchar *Name,size_t MaxNameSize,int64 FileSize,RarTi
   }
   else
   {
-    itoa(FileSize,SizeText2);
-    FileTime->GetText(DateStr2,ASIZE(DateStr2),true,false);
+    itoa(FileSize,SizeText2,ASIZE(SizeText2));
+    FileTime->GetText(DateStr2,ASIZE(DateStr2),false);
     eprintf(St(MAskReplace),Name,SizeText1,DateStr1,SizeText2,DateStr2);
   }
 
@@ -96,6 +96,7 @@ void uiMsgStore::Msg()
       Log(Str[0],St(MDataBadCRC),Str[1],Str[0]);
       break;
     case UIERROR_BADPSW:
+    case UIWAIT_BADPSW:
       Log(Str[0],St(MWrongPassword));
       break;
     case UIERROR_MEMORY:
@@ -135,6 +136,7 @@ void uiMsgStore::Msg()
       break;
     case UIERROR_FILECOPYHINT:
       Log(Str[0],St(MCopyErrorHint));
+      mprintf(L"     "); // For progress percent.
       break;
     case UIERROR_DIRCREATE:
       Log(Str[0],St(MExtrErrMkDir),Str[1]);
@@ -228,6 +230,9 @@ void uiMsgStore::Msg()
     case UIERROR_UNKNOWNEXTRA:
       Log(Str[0],St(MUnknownExtra),Str[1]);
       break;
+    case UIERROR_CORRUPTEXTRA:
+      Log(Str[0],St(MUnknownExtra),Str[1],Str[2]);
+      break;
 #endif
 #if !defined(SFX_MODULE) && defined(_WIN_ALL)
     case UIERROR_NTFSREQUIRED:
@@ -342,14 +347,15 @@ void uiAlarm(UIALARM_TYPE Type)
 {
   if (uiSoundEnabled)
   {
-    static clock_t LastTime=clock();
-    if ((clock()-LastTime)/CLOCKS_PER_SEC>5)
+    static clock_t LastTime=-10; // Negative to always beep first time.
+    if ((MonoClock()-LastTime)/CLOCKS_PER_SEC>5)
     {
 #ifdef _WIN_ALL
       MessageBeep(-1);
 #else
       putwchar('\007');
 #endif
+      LastTime=MonoClock();
     }
   }
 }
